aboutsummaryrefslogtreecommitdiffhomepage
path: root/unsupported/test/cxx11_tensor_morphing_sycl.cpp
diff options
context:
space:
mode:
authorGravatar Mehdi Goli <mehdi.goli@codeplay.com>2016-11-23 16:30:41 +0000
committerGravatar Mehdi Goli <mehdi.goli@codeplay.com>2016-11-23 16:30:41 +0000
commitb8cc5635d581d3b3ea9950ce8359681ae01491a2 (patch)
treefe2af800157e6ffbb02d593e0ebb860bff0cba16 /unsupported/test/cxx11_tensor_morphing_sycl.cpp
parentf11da1d83b64f66252dcce17447c63bda2c663b7 (diff)
Removing unsupported device from test case; cleaning the tensor device sycl.
Diffstat (limited to 'unsupported/test/cxx11_tensor_morphing_sycl.cpp')
-rw-r--r--unsupported/test/cxx11_tensor_morphing_sycl.cpp18
1 files changed, 8 insertions, 10 deletions
diff --git a/unsupported/test/cxx11_tensor_morphing_sycl.cpp b/unsupported/test/cxx11_tensor_morphing_sycl.cpp
index a16e1caf5..4ca73ea1b 100644
--- a/unsupported/test/cxx11_tensor_morphing_sycl.cpp
+++ b/unsupported/test/cxx11_tensor_morphing_sycl.cpp
@@ -82,14 +82,12 @@ template<typename DataType, typename dev_Selector> void sycl_slicing_test_per_de
}
void test_cxx11_tensor_morphing_sycl()
{
- /// Currentlly it only works on cpu. Adding GPU cause LLVM ERROR in cunstructing OpenCL Kernel at runtime.
-// printf("Test on GPU: OpenCL\n");
-// CALL_SUBTEST(sycl_device_test_per_device((cl::sycl::gpu_selector())));
- printf("repeating the test on CPU: OpenCL\n");
- CALL_SUBTEST(sycl_slicing_test_per_device<float>((cl::sycl::cpu_selector())));
- printf("repeating the test on CPU: HOST\n");
- CALL_SUBTEST(sycl_slicing_test_per_device<float>((cl::sycl::host_selector())));
- printf("Test Passed******************\n" );
-
-
+ for (const auto& device : cl::sycl::device::get_devices()) {
+ /// get_devices returns all the available opencl devices. Either use device_selector or exclude devices that computecpp does not support (AMD OpenCL for CPU )
+ /// Currentlly it only works on cpu. Adding GPU cause LLVM ERROR in cunstructing OpenCL Kernel at runtime.
+ auto s= device.template get_info<cl::sycl::info::device::vendor>();
+ std::transform(s.begin(), s.end(), s.begin(), ::tolower);
+ if(device.is_cpu() && s.find("amd")==std::string::npos)
+ CALL_SUBTEST(sycl_slicing_test_per_device<float>(device));
+ }
}